<?php

namespace General\Services\LandingPage\ChargeFeedBack;

use App\Consts\BaseConst;
use General\Models\Report\ReportUserBindRecord;
use General\Models\Report\ReportUserChargeRecord;
use General\Models\User\User;
use General\Services\LandingPage\Report;
use General\Services\Report\BaseReport;
use General\Services\Report\QappTxadqNewReport;
use General\Services\Report\QappXimalayaReport;

/**
 * qapp付费重传
 */
class QappRereport extends Rereport
{
    public function reportInstance(string $link_source): BaseReport
    {
        $name  = 'Qapp' . ucfirst($link_source) . 'Report';
        $namespace = "\\General\\Services\\Report\\{$name}";
        $instance = new $namespace;
        return $instance;
    }

    public function addReportCount(ReportUserBindRecord $report_user): array
    {
        $service = new Report;
        $user = User::find($report_user->uid);
        \Log::info('addReportCount:'.$report_user->uid.' user_data:'.json_encode($user));
        
        return $service->report('api/report/add', [
            'source' => BaseConst::Platform,
            'adid' => $report_user->adid,
            'channel_id' => $user->distribution_channel_id,
            'send_order_id' => $user->send_order_id,
        ]);
    }

    public function reReport(int $bind_id, float $amount, string $order_no)
    {
        $report_user = ReportUserBindRecord::find($bind_id);
        if ($report_user) {
            /**
             * 腾讯adq新版特殊对待一下
             */
            if($report_user->platform == 'tx_adq_new') {
                $result = QappTxadqNewReport::reportCharge($report_user, $order_no, $amount);
                ReportUserChargeRecord::updateOrCreate(
                    [
                        'order_no' => $order_no,
                    ],
                    [
                        'uid' => $report_user->uid,
                        'status' => $result['result'],
                        'content' => $result['result'] ? '手动回传' : $result['content'],
                    ]
                );
            }
            else if($report_user->platform=='ximalaya') {
                $result = QappXimalayaReport::reportCharge($report_user);
                ReportUserChargeRecord::updateOrCreate(
                    [
                        'order_no' => $order_no,
                    ],
                    [
                        'uid' => $report_user->uid,
                        'status' => $result['result'],
                        'content' => $result['result'] ? '手动回传' : $result['content'],
                    ]
                );
            }
            else {
                $instance = $this->reportInstance($report_user->platform);
                $result =  $instance->reportCharge($report_user, $amount);
                $charge = ReportUserChargeRecord::updateOrCreate(
                    [
                        'order_no' => $order_no,
                    ],
                    [
                        'uid' => $report_user->uid,
                        'status' => $result['result'],
                        'content' => $result['result'] ? '手动回传' : $result['content'],
                    ]
                );
                \Log::info('start_addReportCount:'.json_encode($report_user));
                $report_info = $this->addReportCount($report_user);
                \Log::info('end_addReportCount:'.json_encode($report_info));

                if ($report_info && isset($report_info['data']['percent'])) {
                    $charge->report_percent = $report_info['data']['percent'];
                    $charge->save();
                }
            }

        }
    }
}
